diff --git a/util/gedit/README.md b/util/gedit/README.md
deleted file mode 100644
index 5410afec10..0000000000
--- a/util/gedit/README.md
+++ /dev/null
@@ -1,7 +0,0 @@
-### How to Install?
-
-There are two ways to install the configuration file
-
-1. Run the installer
-
-2. Copy ```hip.lang``` file to ```/usr/share/gtksourceview-3.0/language-specs```
diff --git a/util/gedit/hip.lang b/util/gedit/hip.lang
deleted file mode 100644
index f768f2ed94..0000000000
--- a/util/gedit/hip.lang
+++ /dev/null
@@ -1,308 +0,0 @@
-
-
-
-
- *.cpp;*.c;*.cu
- //
- /*
- */
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
- __global__
- __host__
- __device__
- __constant__
- __shared__
- __kernel__
-
-
-
-
-
- uint
- int1
- uint1
- int2
- uint2
- int3
- uint3
- int4
- uint4
- float1
- float2
- float3
- float4
- char1
- char2
- char3
- char4
- uchar1
- uchar2
- uchar3
- uchar4
- short1
- short2
- short3
- short4
- dim1
- dim2
- dim3
- dim4
-
-
-
- hipThreadIdx_x
- hipThreadIdx_y
- hipThreadIdx_z
- hipBlockDim_x
- hipBlockDim_y
- hipBlockDim_z
- hipBlockIdx_x
- hipBlockIdx_y
- hipBlockIdx_z
- hipGridIdx_x
- hipGridIdx_y
- hipGridIdx_z
-
-
-
- atomicAdd
- atomicAnd
- atomicCAS
- atomicDec
- atomicExch
- atomicInc
- atomicMax
- atomicMin
- atomicOr
- atomicSub
- atomicXor
-
-
-
- tex1D
- tex1Dfetch
- tex2D
- __float_as_int
- __int_as_float
- __float2int_rn
- __float2int_rz
- __float2int_ru
- __float2int_rd
- __float2uint_rn
- __float2uint_rz
- __float2uint_ru
- __float2uint_rd
- __int2float_rn
- __int2float_rz
- __int2float_ru
- __int2float_rd
- __uint2float_rn
- __uint2float_rz
- __uint2float_ru
- __uint2float_rd
- __fadd_rz
- __fmul_rz
- __fdividef
- __mul24
- __umul24
- __mulhi
- __umulhi
- __mul64hi
- __umul64hi
- min
- umin
- fminf
- fmin
- max
- umax
- fmaxf
- fmax
- abs
- fabsf
- fabs
- sqrtf
- sqrt
- sinf
- __sinf
- sin
- cosf
- __cosf
- cos
- sincosf
- __sincosf
- expf
- __expf
- exp
- logf
- __logf
- log
-
-
-
- hipBindTexture
- hipBindTextureToArray
- hipChooseDevice
- hipConfigureCall
- hipCreateChannelDesc
- hipD3D10GetDevice
- hipD3D10MapResources
- hipD3D10RegisterResource
- hipD3D10ResourceGetMappedArray
- hipD3D10ResourceGetMappedPitch
- hipD3D10ResourceGetMappedPointer
- hipD3D10ResourceGetMappedSize
- hipD3D10ResourceGetSurfaceDimensions
- hipD3D10ResourceSetMapFlags
- hipD3D10SetDirect3DDevice
- hipD3D10UnmapResources
- hipD3D10UnregisterResource
- hipD3D9GetDevice
- hipD3D9GetDirect3DDevice
- hipD3D9MapResources
- hipD3D9RegisterResource
- hipD3D9ResourceGetMappedArray
- hipD3D9ResourceGetMappedPitch
- hipD3D9ResourceGetMappedPointer
- hipD3D9ResourceGetMappedSize
- hipD3D9ResourceGetSurfaceDimensions
- hipD3D9ResourceSetMapFlags
- hipD3D9SetDirect3DDevice
- hipD3D9UnmapResources
- hipD3D9UnregisterResource
- hipGetDeviceProperties
- hipDeviceSynchronize
- hipEventCreate
- hipEventDestroy
- hipEventElapsedTime
- hipEventQuery
- hipEventRecord
- hipEventSynchronize
- hipFree
- hipFreeArray
- hipFreeHost
- hipGetChannelDesc
- hipGetDevice
- hipGetDeviceCount
- hipGetDeviceProperties
- hipGetErrorString
- hipGetLastError
- hipGetSymbolAddress
- hipGetSymbolSize
- hipGetTextureAlignmentOffset
- hipGetTextureReference
- hipGLMapBufferObject
- hipGLRegisterBufferObject
- hipGLSetGLDevice
- hipGLUnmapBufferObject
- hipGLUnregisterBufferObject
- hipLaunch
- hipLaunchKernel
- hipMalloc
- hipMalloc3D
- hipMalloc3DArray
- hipMallocArray
- hipMallocHost
- hipMallocPitch
- hipMemcpy
- hipMemcpy2D
- hipMemcpy2DArrayToArray
- hipMemcpy2DFromArray
- hipMemcpy2DToArray
- hipMemcpy3D
- hipMemcpyArrayToArray
- hipMemcpyFromArray
- hipMemcpyFromSymbol
- hipMemcpyToArray
- hipMemcpyToSymbol
- hipMemset
- hipMemset2D
- hipMemset3D
- hipSetDevice
- hipSetupArgument
- hipStreamCreate
- hipStreamDestroy
- hipStreamQuery
- hipStreamSynchronize
- hipThreadExit
- hipThreadSynchronize
- hipUnbindTexture
-
-
-
- hipDeviceProp_t
- hipError_t
- hipFilterModePoint
- hipMemcpyHostToDevice
- hipMemcpyDeviceToHost
- hipReadModeElementType
- hipSuccess
- hipTextureType1D
-
-
-
-
-
-
-
-
-
-
-
-
-
diff --git a/util/gedit/install.sh b/util/gedit/install.sh
deleted file mode 100644
index fc4c589ba3..0000000000
--- a/util/gedit/install.sh
+++ /dev/null
@@ -1,22 +0,0 @@
-#!/bin/bash
-# Copyright (c) 2016 - 2021 Advanced Micro Devices, Inc. All rights reserved.
-#
-# Permission is hereby granted, free of charge, to any person obtaining a copy
-# of this software and associated documentation files (the "Software"), to deal
-# in the Software without restriction, including without limitation the rights
-# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
-# copies of the Software, and to permit persons to whom the Software is
-# furnished to do so, subject to the following conditions:
-#
-# The above copyright notice and this permission notice shall be included in
-# all copies or substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
-# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
-# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
-# THE SOFTWARE.
-
-sudo cp ./hip.lang /usr/share/gtksourceview-3.0/language-specs
diff --git a/util/vim/README.md b/util/vim/README.md
deleted file mode 100644
index 84571a939e..0000000000
--- a/util/vim/README.md
+++ /dev/null
@@ -1,16 +0,0 @@
-### How to install?
-
-1. Add the hip.vim to ~/.vim/syntax/ directory
-2. Add the following text to the end of ~/.vimrc
-
-```shell
-augroup filetypedetect
- au BufNewFile,BufRead *.cpp set filetype=cpp syntax=hip
-augroup END
-augroup filetypedetect
- au BufNewFile,BufRead *.c set filetype=c syntax=hip
-augroup END
-augroup filetypedetect
- au BufNewFile,BufRead *.cu set filetype=cu syntax=hip
-augroup END
-```
diff --git a/util/vim/hip.vim b/util/vim/hip.vim
deleted file mode 100644
index 02d6a750f2..0000000000
--- a/util/vim/hip.vim
+++ /dev/null
@@ -1,224 +0,0 @@
-" Vim syntax file
-" Language: HIP
-" Maintainer: Aditya Atluri
-
-if exists("b:current_syntax")
- finish
-endif
-
-" Read the C syntax to start with
-if version < 600
- so :p:h/cpp.vim
-else
- runtime! syntax/cpp.vim
- unlet b:current_syntax
-endif
-
-syn case ignore
-
-" hip keywords:
-
-syn keyword hipType __global__ __host__ __device__ __constant__ __shared__ __kernel__
-syn keyword hipKeyword hipThreadIdx_x hipThreadIdx_y hipThreadIdx_z
-syn keyword hipKeyword hipBlockDim_x hipBlockDim_y hipBlockDim_z
-syn keyword hipKeyword hipBlockIdx_x hipBlockIdx_y hipBlockIdx_z
-syn keyword hipKeyword hipGridIdx_x hipGridIdx_y hipGridIdx_z
-syn keyword hipKeyword hipGridDim_x hipGridDim_y hipGridDim_z
-
-syn keyword hipType uint uint1 uint2 uint3 uint4
-syn keyword hipType int1 int2 int3 int4
-syn keyword hipType float1 float2 float3 float4
-syn keyword hipType char1 char2 char3 char4
-syn keyword hipType uchar1 uchar2 uchar3 uchar4
-syn keyword hipType short1 short2 short3 short4
-syn keyword hipType dim1 dim2 dim3 dim4
-syn keyword hipType hipLaunchParm
-
-" Atomic functions
-syn keyword hipFunctionName atomicAdd atomicAnd atomicCAS atomicDec atomicExch
-syn keyword hipFunctionName atomicInc atomicMax atomicMin atomicOr atomicSub atomicXor
-
-" Texture functions
-syn keyword hipFunctionName tex1D tex1Dfetch tex2D
-
-" Type conversion functions
-syn keyword hipFunctionName __float_as_int __int_as_float __float2int_rn
-syn keyword hipFunctionName __float2int_rz __float2int_ru __float2int_rd
-syn keyword hipFunctionName __float2uint_rn __float2uint_rz __float2uint_ru
-syn keyword hipFunctionName __float2uint_rd __int2float_rn __int2float_rz
-syn keyword hipFunctionName __int2float_ru __int2float_rd
-syn keyword hipFunctionName __uint2float_rn __uint2float_rz __uint2float_ru __uint2float_rd
-
-" Intrinsic Math functions
-syn keyword hipFunctionName __fadd_rz __fmul_rz __fdividef
-syn keyword hipFunctionName __mul24 __umul24
-syn keyword hipFunctionName __mulhi __umulhi
-syn keyword hipFunctionName __mul64hi __umul64hi
-
-" Math functions
-syn keyword hipFunctionName min umin fminf fmin max umax fmaxf fmax
-syn keyword hipFunctionName abs fabsf fabs sqrtf sqrt
-syn keyword hipFunctionName sinf __sinf sin cosf __cosf cos sincosf __sincosf
-syn keyword hipFunctionName expf __expf exp logf __logf log
-
-" Runtime Data Types
-syn keyword hipType hipDeviceProp_t
-syn keyword hipType hipError_t
-syn keyword hipType hipStream_t
-syn keyword hipType hipEvent_t
-
-" Runtime functions
-syn keyword hipFunctionName hipBindTexture hipBindTextureToArray
-syn keyword hipFunctionName hipChooseDevice hipConfigureCall hipCreateChannelDesc
-syn keyword hipFunctionName hipD3D10GetDevice hipD3D10MapResources
-syn keyword hipFunctionName hipD3D10RegisterResource hipD3D10ResourceGetMappedArray
-syn keyword hipFunctionName hipD3D10ResourceGetMappedPitch
-syn keyword hipFunctionName hipD3D10ResourceGetMappedPointer
-syn keyword hipFunctionName hipD3D10ResourceGetMappedSize
-syn keyword hipFunctionName hipD3D10ResourceGetSurfaceDimensions
-syn keyword hipFunctionName hipD3D10ResourceSetMapFlags
-syn keyword hipFunctionName hipD3D10SetDirect3DDevice
-syn keyword hipFunctionName hipD3D10UnmapResources
-syn keyword hipFunctionName hipD3D10UnregisterResource
-syn keyword hipFunctionName hipD3D9GetDevice
-syn keyword hipFunctionName hipD3D9GetDirect3DDevice
-syn keyword hipFunctionName hipD3D9MapResources
-syn keyword hipFunctionName hipD3D9RegisterResource
-syn keyword hipFunctionName hipD3D9ResourceGetMappedArray
-syn keyword hipFunctionName hipD3D9ResourceGetMappedPitch
-syn keyword hipFunctionName hipD3D9ResourceGetMappedPointer
-syn keyword hipFunctionName hipD3D9ResourceGetMappedSize
-syn keyword hipFunctionName hipD3D9ResourceGetSurfaceDimensions
-syn keyword hipFunctionName hipD3D9ResourceSetMapFlags
-syn keyword hipFunctionName hipD3D9SetDirect3DDevice
-syn keyword hipFunctionName hipD3D9UnmapResources
-syn keyword hipFunctionName hipD3D9UnregisterResource
-syn keyword hipFunctionName hipGetDeviceProperties
-syn keyword hipFunctionName hipDeviceSynchronize
-syn keyword hipFunctionName hipDeviceReset
-syn keyword hipFunctionName hipEventCreate
-syn keyword hipFunctionName hipEventDestroy
-syn keyword hipFunctionName hipEventElapsedTime
-syn keyword hipFunctionName hipEventQuery
-syn keyword hipFunctionName hipEventRecord
-syn keyword hipFunctionName hipEventSynchronize
-syn keyword hipFunctionName hipFree
-syn keyword hipFunctionName hipFreeArray
-syn keyword hipFunctionName hipHostMalloc
-syn keyword hipFunctionName hipHostAlloc
-syn keyword hipFunctionName hipHostFree
-syn keyword hipFunctionName hipFreeHost
-syn keyword hipFunctionName hipHostGetDevicePointer
-syn keyword hipFunctionName hipHostGetFlags
-syn keyword hipFunctionName hipHostRegister
-syn keyword hipFunctionName hipHostUnregister
-
-syn keyword hipFunctionName hipGetChannelDesc
-syn keyword hipFunctionName hipGetDevice
-syn keyword hipFunctionName hipGetDeviceCount
-syn keyword hipFunctionName hipGetDeviceProperties
-syn keyword hipFunctionName hipGetErrorString
-syn keyword hipFunctionName hipGetLastError
-syn keyword hipFunctionName hipGetSymbolAddress
-syn keyword hipFunctionName hipGetSymbolSize
-syn keyword hipFunctionName hipGetTextureAlignmentOffset
-syn keyword hipFunctionName hipGetTextureReference
-syn keyword hipFunctionName hipGLMapBufferObject
-syn keyword hipFunctionName hipGLRegisterBufferObject
-syn keyword hipFunctionName hipGLSetGLDevice
-syn keyword hipFunctionName hipGLUnmapBufferObject
-syn keyword hipFunctionName hipGLUnregisterBufferObject
-syn keyword hipFunctionName hipLaunchKernel
-syn keyword hipFunctionName hipLaunchParm
-syn keyword hipFunctionName hipMalloc
-syn keyword hipFunctionName hipMalloc3D
-syn keyword hipFunctionName hipMalloc3DArray
-syn keyword hipFunctionName hipMallocArray
-syn keyword hipFunctionName hipMallocHost
-syn keyword hipFunctionName hipMallocPitch
-syn keyword hipFunctionName hipMemcpy
-syn keyword hipFunctionName hipMemcpyAsync
-syn keyword hipFunctionName hipMemcpy2D
-syn keyword hipFunctionName hipMemcpy2DArrayToArray
-syn keyword hipFunctionName hipMemcpy2DFromArray
-syn keyword hipFunctionName hipMemcpy2DToArray
-syn keyword hipFunctionName hipMemcpy3D
-syn keyword hipFunctionName hipMemcpyArrayToArray
-syn keyword hipFunctionName hipMemcpyFromArray
-syn keyword hipFunctionName hipMemcpyFromSymbol
-syn keyword hipFunctionName hipMemcpyToArray
-syn keyword hipFunctionName hipMemcpyToSymbol
-syn keyword hipFunctionName hipMemset
-syn keyword hipFunctionName hipMemset2D
-syn keyword hipFunctionName hipMemset3D
-syn keyword hipFunctionName hipSetDevice
-syn keyword hipFunctionName hipSetupArgument
-syn keyword hipFunctionName hipStreamCreateWithFlags
-syn keyword hipFunctionName hipStreamCreate
-syn keyword hipFunctionName hipStreamDestroy
-syn keyword hipFunctionName hipStreamQuery
-syn keyword hipFunctionName hipStreamSynchronize
-syn keyword hipFunctionName hipThreadExit
-syn keyword hipFunctionName hipThreadSynchronize
-syn keyword hipFunctionName hipUnbindTexture
-syn keyword hipFunctionName hipDeviceCanAccessPeer
-syn keyword hipFunctionName hipDeviceEnablePeerAccess
-syn keyword hipFunctionName hipDeviceDisablePeerAccess
-syn keyword hipFunctionName hipMemcpyPeer
-syn keyword hipFunctionName hipMemcpyPeerAsync
-
-
-" HIP Flags
-syn keyword hipFlags hipFilterModePoint
-syn keyword hipFlags hipMemcpyHostToDevice
-syn keyword hipFlags hipMemcpyDeviceToDevice
-syn keyword hipFlags hipMemcpyHostToHost
-syn keyword hipFlags hipMemcpyDeviceToHost
-syn keyword hipFlags hipMemcpyHostToHost
-syn keyword hipFlags hipMemcpyDeviceToDevice
-syn keyword hipFlags hipMemcpyDefault
-syn keyword hipFlags hipReadModeElementType
-syn keyword hipFlags hipSuccess
-syn keyword hipFlags hipErrorNotReady
-syn keyword hipFlags hipTextureType1D
-
-
-syn keyword hipFlags hipHostMallocDefault
-syn keyword hipFlags hipHostMallocPortable
-syn keyword hipFlags hipHostMallocMapped
-syn keyword hipFlags hipHostMallocWriteCombined
-syn keyword hipFlags hipHostMallocCoherent
-syn keyword hipFlags hipHostMallocNonCoherent
-syn keyword hipFlags hipHostMallocNumaUser
-
-syn keyword hipFlags hipHostAllocDefault
-syn keyword hipFlags hipHostAllocPortable
-syn keyword hipFlags hipHostAllocMapped
-syn keyword hipFlags hipHostAllocWriteCombined
-
-syn keyword hipFlags hipHostRegisterDefault
-syn keyword hipFlags hipHostRegisterPortable
-syn keyword hipFlags hipHostRegisterMapped
-syn keyword hipFlags hipHostRegisterIoMemory
-
-" Define the default highlighting.
-" For version 5.7 and earlier: only when not done already
-" For version 5.8 and later: only when an item doesn't have highlighting yet
-if version >= 508 || !exists("did_c_syn_inits")
- if version < 508
- let did_c_syn_inits = 1
- command -nargs=+ HiLink hi link
- else
- command -nargs=+ HiLink hi def link
- endif
-
- HiLink hipType Type
- HiLink hipKeyword Statement
- HiLink hipFlags Boolean
- HiLink hipFunctionName Function
-
-
- delcommand HiLink
-endif
-
-let b:current_syntax = "hip"